# phy-contrib

[![Build Status](https://img.shields.io/travis/kwikteam/phy-contrib.svg)](https://travis-ci.org/kwikteam/phy-contrib)
[![codecov.io](https://img.shields.io/codecov/c/github/kwikteam/phy-contrib.svg)](http://codecov.io/github/kwikteam/phy-contrib?branch=master)
[![PyPI release](https://img.shields.io/pypi/v/phy-contrib.svg)](https://pypi.python.org/pypi/phy-contrib)

Plugins for [**phy**](https://github.com/kwikteam/phy).

**This repository is not ready for public use yet.**

If you want to try the development version, you first need to install phy. Then you can install phy-contrib with:

```
git clone https://github.com/kwikteam/phy-contrib.git
cd phy-contrib
python setup.py develop
```

To update to the latest development version, do:

```
cd phy-contrib
git pull
```
